@@ -142,7 +142,8 @@ class DeskbarApplet:
 			gobject.source_remove(self.start_query_id)
 				
 		for modctx in self.module_list:
-			if modctx.module.is_async():
+			if modctx.module.is_async() and modctx.enabled:
+				#print "DeskbarApplet: Stopping", modctx.module,"by", sender # DEBUG
 				modctx.module.stop_query()
 				
 	def on_request_keybinding (self, sender, match, keybinding):
@@ -225,17 +226,11 @@ class DeskbarApplet:
 			get_deskbar_history().load(self.module_list)
 							
 	def on_applet_button_press(self, widget, event):
-		try:
-			# GNOME 2.12
-			self.applet.request_focus(long(event.time))
-		except AttributeError:
-			pass
-			
 		# Left-Mouse-Button should focus the GtkEntry widget (for Fitt's Law
 		# - so that a click on applet border on edge of screen activates the
 		# most important widget).
 		if event.button == 1:
-			self.ui.recieve_focus()
+			self.ui.receive_focus(event.time)
 			return True
 		
 		# Middle click handling, we need this in the cuemiac
@@ -247,22 +242,11 @@ class DeskbarApplet:
 	
 	def on_keybinding_button_press(self, widget, time):
 		print 'Keybinding activated, focusing UI'
-		try:
-			# GNOME 2.12
-			self.applet.request_focus(time)
-		except AttributeError:
-			pass
-		self.ui.recieve_focus()
+		self.ui.receive_focus(time)
 		
 	def on_history_item_selection (self, item, match, text):
 		pass
-	
-	def on_keybinding_activated(self, binder, time):
-		# We want to grab focus here
-		print 'Focusing the deskbar-applet entry'
-		self.applet.request_focus(time)
-		# Call receive focus
-		
+			
 	def on_keybinding_changed(self, binder, bound):
 		# FIXME: provide visual clue when not bound
 		# FIXME: should be used in the pref window
