@@ -10,9 +10,10 @@ def _check_requirements():
 	try:
 		import deskbar
 		import beagle
+		beagle.Client()
 		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	except:
-		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Could not load beagle, libbeagle has been compiled without python bindings", None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Could not load beagle, libbeagle has been compiled without python bindings or beagle isn't running", None)
 	
 HANDLERS = {
 	"BeagleLiveHandler" : {
@@ -55,7 +56,6 @@ TYPES = {
 		"extra": {"sender":("fixme:from_name", "parent:fixme:from_name")},
 		#translators: First %s is mail sender, second %s is mail subject.
 		"description": _("View email from <i>%(sender)s</i>: <b>%(name)s</b>"),
-		"snippet": True,
 		"category": "documents",
 		},
 	"File" 		: {
@@ -170,7 +170,7 @@ class BeagleLiveMatch (deskbar.Match.Match):
 	
 		# Retrieve the associated action
 		action = TYPES[self.result["type"]]["action"] % self.result
-		args = ' '.split(action)
+		args = action.split(" ")
 
 		print "BeagleLive spawning:", action, args
 		gobject.spawn_async(args, flags=gobject.SPAWN_SEARCH_PATH)
@@ -221,7 +221,9 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 	
 	def _on_snippet_closed(self, request, query, container, qstring, qmax):
 		if container.snippet == None:
-			self._on_hit_added(query, container.hit, qstring, qmax)
+			self._on_hit_added(query, container, qstring, qmax)
+			
+		container.hit.unref()
 			
 	def _on_hit_added(self, query, hit, qstring, qmax):
 		fire_signal = False
@@ -287,7 +289,7 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 					result[prop] = _("?")
 					
 		self.counter[qstring][hit.get_type()] = self.counter[qstring][hit.get_type()] +1
-		
+
 		match = BeagleLiveMatch(self, result)
 		if fire_signal:
 			self.emit_query_ready(qstring, [match])
@@ -303,6 +305,7 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 				req.set_query(query)
 				req.set_hit(hit)
 				container = SnippetContainer(hit)
+				hit.ref()
 				req.connect('response', self._on_snippet_received, query, container, qstring, qmax)
 				req.connect('closed', self._on_snippet_closed, query, container, qstring, qmax)
 				self.beagle.send_request_async(req)
