@@ -3,8 +3,8 @@ from os.path import join, expanduser, exists, basename
 from gettext import gettext as _
 
 import gtk
-from deskbar.filewatcher import FileWatcher, DirWatcher
-import deskbar, deskbar.indexer, deskbar.handler
+from deskbar.Watcher import FileWatcher, DirWatcher
+import deskbar, deskbar.Indexer, deskbar.Handler
 
 # Check for presence of set to be compatible with python 2.3
 try:
@@ -12,28 +12,32 @@ try:
 except NameError:
 	from sets import Set as set
 
-from deskbar.handlers_browsers import is_preferred_browser
-from deskbar.handlers_browsers import BrowserSmartMatch, BrowserMatch
+from deskbar.BrowserMatch import is_preferred_browser
+from deskbar.BrowserMatch import BrowserSmartMatch, BrowserMatch
 
+def _on_customize_search_engines():
+	pass
+	
 def _check_requirements():
-	if deskbar.UNINSTALLED_DESKBAR:
-		return (True, None)
-		
+#	if deskbar.UNINSTALLED_DESKBAR:
+#		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
+	
+	#We will need to pass some preference here to select one/all engines
 	if is_preferred_browser("firefox") or is_preferred_browser("mozilla"):
-		return (True, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	else:
-		return (False, "Mozilla/Firefox is not your preferred browser, not using it.")
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Mozilla/Firefox is not your preferred browser, not using it.", None)
 		
 HANDLERS = {
 	"MozillaBookmarksHandler" : {
-		"name": _("Bookmarks"),
-		"description": _("Index your bookmarks"),
-		"requirements": _check_requirements,
+		"name": _("Web Bookmarks"),
+		"description": _("Open your web bookmarks by name"),
+		"requirements": _check_requirements
 	},
 	"MozillaSearchHandler" : {
-		"name": _("Search Engines"),
-		"description": _("Index your search engines"),
-		"requirements": _check_requirements,
+		"name": _("Web Searches"),
+		"description": _("Search the web via your browser's search settings"),
+		"requirements": _check_requirements
 	}
 }
 
@@ -42,9 +46,9 @@ USING_FIREFOX = False
 if is_preferred_browser("firefox"):
 	USING_FIREFOX = True
 			
-class MozillaBookmarksHandler(deskbar.handler.Handler):
+class MozillaBookmarksHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "web-bookmark.png")
+		deskbar.Handler.Handler.__init__(self, "stock_bookmark")
 		self._bookmarks = None
 	
 	def initialize(self):
@@ -58,26 +62,61 @@ class MozillaBookmarksHandler(deskbar.handler.Handler):
 			self.watcher.add(parsed_file)
 		
 	def _parse_bookmarks(self):
-		self._bookmarks, parsed_file = MozillaBookmarksParser(self).get_indexer()
+		self._bookmarks, parsed_file, self._shortcuts_to_smart_bookmarks_map = MozillaBookmarksParser(self).get_indexer()
 		return parsed_file
 	
 	def stop(self):
 		self.watcher.remove_all()
 		
-	def query(self, query, max=5):
-		return self._bookmarks.look_up(query)[:max]
+	def query(self, query, max):
+		# First, check the smart bookmarks, or "keywords", where
+		# "wp Foo" takes you to the wikipedia entry for Foo.
+		x = self.query_smart_bookmarks(query, max)
+		if x != None:
+			return x
+		else:
+			# If none of the smart bookmarks matched as a prefix,
+			# then we'll just look up all bookmarks.
+			return self._bookmarks.look_up(query)[:max]
+	
+	def query_smart_bookmarks(self, query, max):
+		# if one of the smart bookmarks' shortcuts matches as a prefix,
+		# then only return that bookmark
+		x = query.find(" ")
+		if x != -1:
+			prefix = query[:x]
+			try:
+				b = self._shortcuts_to_smart_bookmarks_map[prefix]
+				text = query[x+1:]
+				return [BrowserSmartMatch(b.get_handler(), b.name, b.url, prefix, b, icon=b.icon)]
+			except KeyError:
+				# Probably from the b = ... line.  Getting here
+				# means that there is no such shortcut.
+				pass
+		return None
 
-class MozillaSearchHandler(deskbar.handler.Handler):
+class MozillaSearchHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "web-bookmark.png")
+		deskbar.Handler.Handler.__init__(self, "stock_bookmark")
 		self._smart_bookmarks = None
 	
 	def initialize(self):
 		smart_dirs = None
 		if USING_FIREFOX:
-			smart_dirs = [get_firefox_home_file("search"), "/usr/lib/mozilla-firefox/searchplugins"]
+			smart_dirs = [
+				get_firefox_home_file("searchplugins"),
+				get_firefox_home_file("search"),
+				expanduser("~/.mozilla/searchplugins"),
+				"/usr/lib/firefox/searchplugins",
+				"/usr/local/lib/firefox/searchplugins",
+				"/usr/lib/mozilla-firefox/searchplugins",
+				"/usr/local/lib/mozilla-firefox/searchplugins"]
 		else:
-			smart_dirs = [get_mozilla_home_file("search"), "/usr/lib/mozilla/searchplugins"]
+			smart_dirs = [
+				get_mozilla_home_file("search"),
+				expanduser("~/.mozilla/searchplugins"),
+				"/usr/lib/mozilla/searchplugins",
+				"/usr/local/lib/mozilla/searchplugins"]
 		
 		if not hasattr(self, 'watcher'):
 			self.watcher = DirWatcher()
@@ -86,13 +125,14 @@ class MozillaSearchHandler(deskbar.handler.Handler):
 		self.watcher.add(smart_dirs)
 		self._parse_search_engines(smart_dirs)
 		
-	def _parse_search_engines(self, smart_dirs):		
+	def _parse_search_engines(self, smart_dirs):	
+		#TODO: if using firefox, show a way to enable only active search engine in a pref dialog.
 		self._smart_bookmarks = MozillaSmartBookmarksDirParser(self, smart_dirs).get_smart_bookmarks()
 
 	def stop(self):
 		self.watcher.remove_all()
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		return self._smart_bookmarks
 		
 class MozillaBookmarksParser(HTMLParser.HTMLParser):
@@ -105,8 +145,9 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 		self.href = None
 		self.icon_data = None
 		self.bookmarks = set()
+		self._shortcuts_to_smart_bookmarks_map = {}
 		
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
 		
 		if USING_FIREFOX:
 			self.indexed_file = self._index_firefox()
@@ -116,10 +157,12 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 		
 	def get_indexer(self):
 		"""
-		Returns a completed indexer with the contents of bookmark file
-		and the name of the indexed file
+		Returns a completed indexer with the contents of bookmark file,
+		the name of the indexed file, and a map from shortcuts (or
+		prefixes) to smart bookmarks - those bookmarks with %s in the
+		URL.
 		"""
-		return (self._indexer, self.indexed_file)
+		return (self._indexer, self.indexed_file, self._shortcuts_to_smart_bookmarks_map)
 		
 	def _index_mozilla(self):
 		try:
@@ -143,11 +186,14 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 		tag = tag.lower()
 		if tag == "a":
 			self.chars = ""
+			self.shortcuturl = None
 			for tag, value in attrs:
 				if tag.lower() == 'href':
 					self.href = value
 				if tag.lower() == 'icon' and value != "data:" and value.startswith("data:"):
 					self.icon_data = value
+				if tag.lower() == 'shortcuturl':
+					self.shortcuturl = value
 
 	def handle_endtag(self, tag):
 		tag = tag.lower()
@@ -175,8 +221,12 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 				# Reset icon data for the following icon
 				self.icon_data = None
 				
-			bookmark = BrowserMatch(self.handler, self.chars, self.href, pixbuf)
-			self._indexer.add("%s %s" % (self.chars, self.href), bookmark)
+			bookmark = BrowserMatch(self.handler, self.chars, self.href, icon=pixbuf)
+			if self.shortcuturl != None:
+				bookmark = BrowserSmartMatch(self.handler, self.chars, self.href, self.shortcuturl, bookmark, icon=pixbuf)
+				self._shortcuts_to_smart_bookmarks_map[self.shortcuturl] = bookmark
+			else:
+				self._indexer.add("%s %s" % (self.chars, self.href), bookmark)
 
 	def handle_data(self, chars):
 		self.chars = self.chars + chars
@@ -373,20 +423,19 @@ class MozillaSmartBookmarksDirParser:
 					continue
 				else:
 					foundbookmarks.append(bmname)
-					
-				pixbuf = None
+				
+				img = None
 				try:
 					img = [img for img in glob.glob(join(bookmarks_dir, '%s.*' % f[:-4])) if not img.endswith(".src")][0]
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(img, deskbar.ICON_SIZE, deskbar.ICON_SIZE)
-				except Exception, msg:
-					print 'Error:MozillaSmartBookmarksDirParser:Cannot load image:%s' % msg
+				except:
+					pass
 				
 				parser = MozillaSmartBookmarksParser(f)
 				try:
 					parser.parse()
 					infos = parser.get_infos()
-					bookmark = BrowserMatch(handler, infos["name"], infos["url"], pixbuf)
-					bookmark = BrowserSmartMatch(bookmark, infos["name"], infos["action"])
+					bookmark = BrowserMatch(handler, infos["name"], infos["url"], icon=img)
+					bookmark = BrowserSmartMatch(handler, infos["name"], infos["action"], icon=img, bookmark=bookmark)
 					self._smart_bookmarks.append(bookmark)
 				except Exception, msg:
 					print 'Error:MozillaSmartBookmarksDirParser:cannot parse smrt bookmark:%s:bookmark %s' % (msg, f)
